@@ -1,3 +1,3 @@
-data = {'Paris': 2_165_423, 'New York City': 8_804_190, 'Tokyo': 13_988_129}
+data = {"Paris": 2_165_423, "New York City": 8_804_190, "Tokyo": 13_988_129}
 for city, population in data:  # [dict-iter-missing-items]
     print(f"{city} has population {population}.")
